@@ -18,36 +18,21 @@
 #include <QApplication>
 #include <QDir>
 
-#include <KAboutData>
-#include <kauth_version.h>
-#if KAUTH_VERSION >= QT_VERSION_CHECK(5, 92, 0)
 #include <KAuth/ExecuteJob>
-#else
-#include <KAuthExecuteJob>
-#endif
 #include <KIO/ApplicationLauncherJob>
+#include <KLazyLocalizedString>
 #include <KLocalizedString>
 #include <KPluginFactory>
 #include <KService>
 #include <KUser>
 
-K_PLUGIN_FACTORY_WITH_JSON(KCMSddmFactory, "../kcm_sddm.json", registerPlugin<SddmKcm>(); registerPlugin<SddmData>();)
+K_PLUGIN_FACTORY_WITH_JSON(KCMSddmFactory, "kcm_sddm.json", registerPlugin<SddmKcm>(); registerPlugin<SddmData>();)
 
-SddmKcm::SddmKcm(QObject *parent, const QVariantList &args)
-    : KQuickAddons::ManagedConfigModule(parent, args)
+SddmKcm::SddmKcm(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args)
+    : KQuickAddons::ManagedConfigModule(parent, metaData, args)
     , m_data(new SddmData(this))
     , m_themesModel(new ThemesModel(this))
 {
-    KAboutData *aboutData = new KAboutData(QStringLiteral("kcm_sddm"), i18n("Login Screen (SDDM)"), QStringLiteral(PROJECT_VERSION));
-
-    aboutData->setShortDescription(i18n("Login screen using the SDDM"));
-    aboutData->setLicense(KAboutLicense::GPL_V2);
-    aboutData->setHomepage(QStringLiteral("https://projects.kde.org/projects/kde/workspace/sddm-kcm"));
-    aboutData->addAuthor(QStringLiteral("Reza Fatahilah Shah"), i18n("Author"), QStringLiteral("rshah0385@kireihana.com"));
-    aboutData->addAuthor(QStringLiteral("David Edmundson"), i18n("Author"), QStringLiteral("davidedmundson@kde.org"));
-    aboutData->addAuthor(QStringLiteral("David Redondo"), i18n("Author"), QStringLiteral("kde@david-redondo.de"));
-
-    setAboutData(aboutData);
     setAuthActionName(QStringLiteral("org.kde.kcontrol.kcmsddm.save"));
 
     qmlRegisterUncreatableType<ThemesModel>("org.kde.private.kcms.sddm", 1, 0, "ThemesModel", QStringLiteral("Cannot create ThemesModel"));
@@ -151,10 +136,11 @@ void SddmKcm::save()
     connect(job, &KJob::result, this, [this, job] {
         if (job->error()) {
             Q_EMIT errorOccured(job->errorString());
-            settingsChanged(); // Re-enable the Apply button
         } else {
             m_data->sddmSettings()->load();
         }
+        // Clarify enable or disable the Apply button.
+        this->setNeedsSave(job->error());
     });
     job->start();
 }
@@ -166,7 +152,7 @@ void SddmKcm::synchronizeSettings()
     // QDir returns "." and true for exists() in the case of a non-existent user;
     QString sddmHomeDirPath = KUser("sddm").homeDir();
     if (sddmHomeDirPath.isEmpty()) {
-        Q_EMIT errorOccured(QStringLiteral("Cannot proceed, user 'sddm' does not exist. Please check your SDDM install."));
+        Q_EMIT errorOccured(kli18n("Cannot proceed, user 'sddm' does not exist. Please check your SDDM install.").untranslatedText());
         return;
     }
 
@@ -283,7 +269,7 @@ void SddmKcm::resetSyncronizedSettings()
     // QDir returns "." and true for exists() in the case of a non-existent user
     QString sddmHomeDirPath = KUser("sddm").homeDir();
     if (sddmHomeDirPath.isEmpty()) {
-        Q_EMIT errorOccured(QStringLiteral("Cannot proceed, user 'sddm' does not exist. Please check your SDDM install."));
+        Q_EMIT errorOccured(kli18n("Cannot proceed, user 'sddm' does not exist. Please check your SDDM install.").untranslatedText());
         return;
     }
 
